ResponsiveHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appScaler → double
-
no setter
- deviceSize → Size
-
no setter
Static Methods
-
h(
double value, {double min = double.negativeInfinity, double max = double.infinity}) → double -
init(
BuildContext context, {Future< String?> loadScale()?}) → Future<void> -
u(
double value, {double min = double.negativeInfinity, double max = double.infinity}) → double -
w(
double value, {double min = double.negativeInfinity, double max = double.infinity}) → double
Constants
- referenceHeight → const double
- referenceWidth → const double